@@ -4,7 +4,7 @@ use warnings;
 use strict;
 $|++;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 #----------------------------------------------------------------------------
 
@@ -31,10 +31,12 @@ Labyrinth::Test::Harness - Test Harness for Labyrinth Plugin modules
     $harness->cleanup;
 
     $harness->clear();
-    my $vars   = $harness->vars;
-    my $params = $harness->params;
-    $harness->set_params( name => 'Test', test => 1 );
+    my $vars     = $harness->vars;
+    my $params   = $harness->params;
+    my $settings = $harness->settings;
     $harness->set_vars( name => 'Test', test => 1 );
+    $harness->set_params( name => 'Test', test => 1 );
+    $harness->set_settings( name => 'Test', test => 1 );
 
     my $error = $harness->error;
 
@@ -237,11 +239,12 @@ sub action {
 }
 
 sub refresh {
-    my ($self,$plugins,$vars,$params) = @_;
+    my ($self,$plugins,$vars,$params,$settings) = @_;
 
     $self->labyrinth(@$plugins);
-    $self->set_vars( %$vars )       if($vars);
-    $self->set_params( %$params )   if($params);
+    $self->set_vars( %$vars )           if($vars);
+    $self->set_params( %$params )       if($params);
+    $self->set_settings( %$settings )   if($settings);
 }
 
 sub login {
@@ -281,6 +284,18 @@ sub set_params {
     }
 }
 
+sub settings {
+    my ($self) = @_;
+    return \%settings;
+}
+
+sub set_settings {
+    my ($self,%hash) = @_;
+    for my $name (keys %hash) {
+        $settings{$name} = $hash{$name}
+    }
+}
+
 sub error {
     my ($self) = @_;
     return $self->{error};
@@ -623,6 +638,14 @@ returns the current variables hash.
 
 Adds the given variables to the current variables hash.
 
+=item settings
+
+returns the current settings hash.
+
+=item set_settings( %hash )
+
+Adds the given variables to the current settings hash.
+
 =item error
 
 Returns the last error recorded.
@@ -669,7 +692,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2014 Barbie for Miss Barbell Productions
+  Copyright (C) 2014-2015 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
